@@ -470,13 +470,13 @@ Arnolfini.IEFixNthChild = function () {
 	$(".threecol div.tileItem:nth-child(3n+2)").addClass("threecolNthChild");
 }
 
-Arnolfini.hideShareCounters = function ()
+Arnolfini.showShareCounters = function ()
 {
 	$('.addthis_counter').each(function ()
 				{
-					if ($(this).text() == '0')
+					if ($(this).text() !== '0')
 					{
-						$(this).hide();
+						$(this).addClass('visible');
 					}
 				});
 }
@@ -507,7 +507,7 @@ $(document).ready(function() {
 		Arnolfini.IEFixNthChild();
 	}
 	
-	setTimeout(Arnolfini.hideShareCounters, 3000);
+	setTimeout(Arnolfini.showShareCounters, 4000);
 	
 	//Fixing the mailchimp error html reading
 	errorText = $('.portletMailChimp dl.error dd').text();
